@@ -1,4 +1,4 @@
-# $Id: Subtitles.pm,v 1.17 2008/09/03 16:29:00 dk Exp $
+# $Id: Subtitles.pm,v 1.20 2010/04/01 14:02:12 dk Exp $
 package Subtitles;
 use strict;
 require Exporter;
@@ -6,7 +6,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK @codecs $VERSION);
 @ISA = qw(Exporter);
 @EXPORT = qw(codecs time2str);
 @EXPORT_OK = qw(codecs time2hms time2shms hms2time time2str);
-$VERSION = '1.01';
+$VERSION = '1.03';
 
 
 push @codecs, map { "Subtitles::Codec::$_" } qw( srt mdvd sub2 smi idx);
@@ -79,9 +79,15 @@ sub load
 {
 	my ( $self, $fh, $codec) = @_;
 	$self-> clear;
+	local $/;
+	my $content = <$fh>;
+	if ( $content =~ s/^(\xff\xfe|\xfe\xff)//) {
+		# found a bom
+		my $le = ( $1 eq "\xff\xfe" ) ? 'v*' : 'n*';
+		$content = join('', map { chr } unpack($le, $content));
+	}
 	my @content;
-	while (<$fh>) {
-		chomp;
+	for ( split "\n", $content) {
 		s/[\s\n\r]+$//;
 		push @content, $_;
 	}
@@ -324,7 +330,7 @@ use vars qw(@ISA);
 
 sub match
 {
-	$_[1] =~ m/^(\d\d):(\d\d):(\d\d)\,(\d\d\d)\s*-->\s*(\d\d):(\d\d):(\d\d)\,(\d\d\d)/;
+	$_[1] =~ m/^(\d\d):(\d\d):(\d\d)[.,](\d\d\d)\s*-->\s*(\d\d):(\d\d):(\d\d)[.,](\d\d\d)/;
 }
 
 sub read
@@ -348,7 +354,7 @@ sub read
 			$stage++;
 		} elsif ( $stage == 1) {
 			die "Invalid timing at line $line\n" unless
-				m/^(\d\d):(\d\d):(\d\d)\,(\d\d\d)\s*-->\s*(\d\d):(\d\d):(\d\d)\,(\d\d\d)/;
+				m/^(\d\d):(\d\d):(\d\d)[.,](\d\d\d)\s*-->\s*(\d\d):(\d\d):(\d\d)[.,](\d\d\d)/;
 			push @{$sub->{from}}, Subtitles::hms2time( $1, $2, $3, $4);
 			push @{$sub->{to}},   Subtitles::hms2time( $5, $6, $7, $8); 
 			$stage++;
